fisx: Member List

fisx

fisx::Shell Member List

This is the complete list of members for fisx::Shell, including all inherited members.

getAugerRatios() const | fisx::Shell |
getCosterKronigRatios() const | fisx::Shell |
getDirectVacancyTransferRatios(const std::string &destination) const | fisx::Shell |
getFluorescenceRatios() const | fisx::Shell |
getFluorescenceYield() const (defined in fisx::Shell) | fisx::Shell |
getNonradiativeTransitions() const (defined in fisx::Shell) | fisx::Shell |
getRadiativeTransitions() const (defined in fisx::Shell) | fisx::Shell |
getShellConstants() const (defined in fisx::Shell) | fisx::Shell |
setNonradiativeTransitions(std::vector< std::string >, std::vector< double > values) | fisx::Shell |
setNonradiativeTransitions(std::map< std::string, double > values) (defined in fisx::Shell) | fisx::Shell |
setNonradiativeTransitions(const char *strings[], const double *values, int nValues) (defined in fisx::Shell) | fisx::Shell |
setRadiativeTransitions(std::map< std::string, double >) | fisx::Shell |
setRadiativeTransitions(std::vector< std::string >, std::vector< double > values) | fisx::Shell |
setRadiativeTransitions(const char *strings[], const double *values, int nValues) | fisx::Shell |
setShellConstants(std::map< std::string, double >) | fisx::Shell |
Shell() (defined in fisx::Shell) | fisx::Shell |
Shell(std::string name) | fisx::Shell |
StringToInteger(const std::string &str, int &number) (defined in fisx::Shell) | fisx::Shell |